@@ -13,7 +13,7 @@ pub enum Variants {
 
 #[derive(FieldAccess, PartialEq, Debug)]
 #[field_access(u32)]
-enum FourBitsVariant {
+pub enum FourBitsVariant {
     Case1 = 0,
     Case2 = 8,
     Case3 = 15,
@@ -28,17 +28,14 @@ pub enum ExternalVariants {
 
 #[test]
 fn can_use_variants() {
-    let mut r = Variants::zero();
-    r.write(Variants::ThreeBits, variants::ThreeBits::FirstOn);
-    assert_eq!(
-        (&r.read(Variants::ThreeBits)).variant(),
-        variants::ThreeBits::FirstOn
-    );
+    let mut r = Variants::new();
+    r.write(Variants::ThreeBits, ThreeBits::FirstOn);
+    assert_eq!((&r.read(Variants::ThreeBits)).variant(), ThreeBits::FirstOn);
 }
 
 #[test]
 fn can_use_external_variants() {
-    let mut r = ExternalVariants::zero();
+    let mut r = ExternalVariants::new();
     r.write(ExternalVariants::FourBits, FourBitsVariant::Case3);
     assert_eq!(
         r.read(ExternalVariants::FourBits).variant(),
